/*
 * This file is part of dial.
 *
 * dial is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 * 
 * dial is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with dial; see the file COPYING.  If not, write to the Free
 * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   Copyright 1994 Dominic Giampaolo
 *   Copyright 1996 Torsten Martinsen
 *
 * $Id: callbacks.c,v 1.21 1996/04/02 15:47:37 torsten Exp $
 */

#include <stdio.h>

#include "dial.h"
#include "readrc.h"

int cstate = CSTATE_NC;

#if SELECTNUMBER
static void listcb(Widget w, char *str, int index, void * junk);
#endif
static void closecb(Widget w, void * junk);
static void totalscb(Widget w, void * junk);


void
connectcb(Widget w, void * junk)
{
  switch (cstate)
    {
    case CSTATE_NC:
      if (number == NULL)
	{
	  number = *getNumberList(NULL);
	  curpreinfo = getPrefixInfo(number);
	}
      sa_printf("Connecting..");
      SetWidgetState(button, FALSE);
      doconnect();
      break;
    case CSTATE_CONNECTED:
    case CSTATE_TRYING:
    case CSTATE_BUSY:
      SetWidgetState(button, FALSE);
      stopclock();
      hangup(hangup_done);
      cstate = CSTATE_NC;
      sa_printf("Not connected");
      break;
    }      
}

void
quitcb(Widget w, void * junk)
{
  if (cstate != CSTATE_NC)
    {
      stopclock();
      hangup(hangup_done);
    }
#if MODULES
#if BSD_COMP
  unload_module("bsd_comp");
#endif
  unload_module("ppp");
  unload_module("slhc");
#endif
  exit(0);
}

#if SELECTNUMBER
/*
 * Allow user to select a phone number from a scrolled list.
 */
void
selectcb(Widget w, void * junk)
{
  static char ** items = NULL; /* NULL-terminated */
  Widget wl;
  static int n;
  
  
  if (items == NULL)
    items = getNumberList(&n);
  
  MakeWindow("Select number", SAME_DISPLAY, EXCLUSIVE_WINDOW);
  wl = MakeScrollList(items, WIDTH, n*FontHeight(titlefont)*8/6, listcb, NULL);
  SetWidgetFont(wl, titlefont);
  ShowDisplay();
  MainLoop();
}

static void
listcb(Widget w, char *str, int index, void * junk)
{
  number = str;
  CloseWindow();
}
#endif

static char ** items, ** totals;
static Widget scrollist, tbutton, label;
static char * itemheader  = "      Start            End          Time      Cost";
static char * totalheader = "Month    Time    Cost                             ";

/*
 * Show statistics on recorded calls.
 */
void
statscb(Widget w, void * junk)
{
  Widget but;
  int n;

  if ((items = getStatistics(&n, &totals)) == NULL)
    return;

  MakeWindow("Statistics", SAME_DISPLAY, EXCLUSIVE_WINDOW);
  label = MakeLabel(totalheader);
  SetWidgetFont(label, titlefont);
  scrollist = MakeScrollList(totals,
			     MIN(STATMAXWIDTH, TextWidth(titlefont, *items)+50),
			     NMONTHS*FontHeight(titlefont)*7/6,
			     NULL, NULL);

  SetWidgetPos(scrollist, PLACE_UNDER, label, NO_CARE, NULL);
  SetWidgetFont(scrollist, titlefont);
  tbutton = MakeButton("Items ", totalscb, NULL);
  SetWidgetFont(tbutton, buttonfont);
  SetWidgetPos(tbutton, PLACE_UNDER, scrollist, NO_CARE, NULL);
  but = MakeButton("Close", closecb, NULL);
  SetWidgetFont(but, buttonfont);
  SetWidgetPos(but, PLACE_UNDER, scrollist, PLACE_RIGHT, tbutton);
  ShowDisplay();
  MainLoop();
}

static void
closecb(Widget w, void * junk)
{
  CloseWindow();
  stat_free();
}

static void
totalscb(Widget w, void * junk)
{
  static int state = 0;

  if (state == 1)
    {
      SetLabel(label, totalheader);
      ChangeScrollList(scrollist, totals);
      SetLabel(tbutton, "Items");
      state = 0;
    }
  else
    {
      SetLabel(label, itemheader);
      ChangeScrollList(scrollist, items);
      SetLabel(tbutton, "Totals");
      state = 1;
    }
}

void
hangup_done(void)
{
  SetLabel(button, "  Connect  ");
  SetWidgetState(button, TRUE);
}
