/*
 * This file is part of dial.
 *
 * dial is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 * 
 * dial is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with dial; see the file COPYING.  If not, write to the Free
 * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   Copyright 1994 Dominic Giampaolo
 *   Copyright 1996 Torsten Martinsen
 *
 * $Id: dial.h,v 1.22 1996/04/02 15:51:36 torsten Exp $
 */

#include "libsx.h"

/*
 * MODULES should be 1 if you have compiled kernel PPP support as a module.
 * 'dial' will then load the modules 'slhc' and 'ppp'.
 * Set BSD_COMP to 1 if you want to use compressed headers.
 * 'dial' will then load the module 'bsd_comp'.
 */
#define MODULES		1
#define BSD_COMP	1

/*
 * If you want dial to show detailed information while connecting, set
 * SHOW_CONNECT_STATUS to 1. For this to work optimally, make sure your chat
 * script includes the sequence
 *
 *	ABORT BUSY ABORT 'NO CARRIER' ABORT 'NO DIALTONE'
 *
 * as shown in 'sample-scripts/ppp-connect'. Also double-check the definition
 * of SYSLOGFILE below.
 * If you set SHOW_CONNECT_STATUS to 0, you need to install the 'ip-up' and
 * 'ip-down' scripts in /etc/ppp - otherwise dial can not tell whether the
 * link is up.
 */
#define SHOW_CONNECT_STATUS	1

/* Define this as 1 if you want to be able to
 * select among several phone numbers.
 */
#define SELECTNUMBER		0

/*
 * These should conform to the Linux FSSTND.
 */
#define PPPD		"/usr/sbin/pppd"	/* Path to PPP daemon */
#define PPPDFILE	"/etc/ppp/linkinfo"	/* Created by /etc/ppp/ip-up */
#define PPPDPIDFILE	"/var/run/ppp0.pid"	/* PID of PPP daemon */
#define CONNECTSCRIPT	"/etc/ppp/dial-ppp-connect"

/*
 * This is the file where pppd messages are logged.
 * If your /etc/syslog.conf has an entry something like
 *	local2.notice;local2.debug			/var/adm/ppp.log
 * then SYSLOGFILE should be defined as "/var/adm/ppp.log".
 * Otherwise, the default should work OK.
 */
#define SYSLOGFILE	"/var/adm/messages"	/* Syslog messages */
#define INSMOD		"/sbin/insmod"		/* Path to insmod */
#define RMMOD		"/sbin/rmmod"		/* Path to rmmod */

/*
 * It should not be necessary to change any of the following defines.
 */
#define WIDTH 130
#define HEIGHT 180
#define STATMAXWIDTH	800
#define STATMAXHEIGHT	600
#define NMONTHS		12	/* # of months shown in Totals window */

#define TITLEFONT	"-b&h-lucidatypewriter-medium-r-*-*-*-180-75-75-*-*-*-*"
#define BUTTONFONT	"-adobe-helvetica-bold-r-*-*-*-140-75-75-*-*-*-*"

#define GREY		"grey"	/* Colour for greyed-out text */

#define TICKINTERVAL 1000	/* How often to update clock (ms) */
#define COSTINTERVAL 5		/* How often to update cost (seconds) */

#define SYSRCFILE	"/etc/dialrc"
#define USERRCFILE	"~/.dialrc"
#define DEFAULTLOGFILE  "~/.dialcosts"

#ifdef __GNUC__
#define MAX(a,b) \
	({typedef _ta = (a), _tb = (b);  \
	_ta _a = (a); _tb _b = (b);     \
	_a > _b ? _a : _b; })
#define MIN(a,b) \
	({typedef _ta = (a), _tb = (b);  \
	_ta _a = (a); _tb _b = (b);     \
	_a < _b ? _a : _b; })
#else
#define MAX(a,b) ((a) > (b) ? (a) : (b))
#define MIN(a,b) ((a) < (b) ? (a) : (b))
#endif

typedef void (*Voidfunc)(void);

/*
 * Globals
 */
extern int cstate;
extern int testing;
extern int greycol;
extern Widget button;
extern char * number;
extern XFont titlefont, buttonfont;


/*
 * Connection states
 */
#define CSTATE_NC	  0
#define CSTATE_CONNECTED  1
#define CSTATE_TRYING	  2
#define CSTATE_BUSY	  3

typedef struct
{
  int redialinterval;
  int connecttimeout;
  int redial;
  float dialcost;
  char * logfile;
} GlobalOptions;

extern GlobalOptions global;

/*
 * Prototypes
 */

/* callbacks.c */
void connectcb(Widget w, void *junk);
void quitcb(Widget w, void *junk);
void selectcb(Widget w, void * junk);
void statscb(Widget w, void * junk);
void hangup_done(void);

/* connect.c */
void doconnect(void);
void hangup(Voidfunc func);

/* cost.c */
void clocktick(void * junk);
void startclock(void);
void stopclock(void);
void log_costs(void);
void add_dial_cost(void);

/* display.c */
void update_display(int doclock, int docost, int dorate);
void set_display(char *clockstr, char *coststr, char *ratestr);
void repaint(Widget w, int new_width, int new_height, void *data);
void repaint1(Widget w, int new_width, int new_height, void *data);
void sa_printf(char * format, ...);
void bannercb(void * junk);

/* modules.c */
void load_module(char * name);
void unload_module(char * name);

/* readrc.c */
void parserc(char * rcfile);
char ** getNumberList(int * np);

/* stats.c */
char ** getStatistics(int * np, char *** totals);
void stat_free(void);
