/*
 * This file is part of dial.
 *
 * dial is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 * 
 * dial is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with dial; see the file COPYING.  If not, write to the Free
 * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   Copyright 1996 Torsten Martinsen
 *
 * $Id: display.c,v 1.14 1996/04/02 15:52:11 torsten Exp $
 */

#include <stdio.h>
#include <stdarg.h>
#include <time.h>

#include "dial.h"


static int dw, dh, dw1, dh1;

static char * clockstring = NULL, * coststring = NULL, * ratestring = NULL;
static int textspacing, starty;
static XFont font, font1;
static Widget da, da1;

static void DrawCenteredText(char *str, XFont font, int width, int y);
static void do_repaint(Widget w);
static void do_repaint1(void);


void
set_display(char * clockstr, char * coststr, char * ratestr)
{
  clockstring = clockstr;
  coststring = coststr;
  ratestring = ratestr;
}

void
update_display(int doclock, int docost, int dorate)
{
  int y;
  char str[20];


  SetDrawArea(da);
  if (cstate != CSTATE_CONNECTED)
    SetColor(greycol);
  
  y = starty+textspacing;

  if (doclock && clockstring)
    DrawCenteredText(clockstring, font, dw, y);
  y += 2*textspacing;
  if (docost && coststring)
    DrawCenteredText(coststring, font, dw, y);
  if (dorate && ratestring)
    {
      y += 2*textspacing;
      strcpy(str, ratestring);
      strcat(str, "/min");
      DrawCenteredText(str, font, dw, y);
    }
  if (cstate != CSTATE_CONNECTED)
    SetColor(BLACK);
}

static void
DrawCenteredText(char * str, XFont font, int width, int y)
{
  DrawText(str, (width-TextWidth(font, str))/2, y);
}

/*
 * Expose callback for the cost window.
 */
void
repaint(Widget w, int new_width, int new_height, void *data)
{
  int fontheight;
  
  dw = new_width;
  dh = new_height;
  da = w;
  
  font = GetWidgetFont(w);
  fontheight = FontHeight(font);
  textspacing = 8*fontheight/6;
  starty = (dh-6*textspacing)/2 + fontheight;

  do_repaint(w);
}

/*
 * Expose callback for the status area.
 */
void
repaint1(Widget w, int new_width, int new_height, void *data)
{
  dw1 = new_width;
  dh1 = new_height;
  da1 = w;
  
  font1 = GetWidgetFont(w);

  do_repaint1();
}

static char statusmsg[80] = "";		/* Current contents of status area */

static void
do_repaint1(void)
{
  SetDrawArea(da1);
  ClearDrawArea();
  DrawCenteredText(statusmsg, font1, dw1, (dh1+FontHeight(font1))/2-2);
}

/*
 * Print a string in the status area and save it so that
 * future repaints will redisplay it.
 */
void
sa_printf(char * format, ...)
{
  va_list args;

  va_start(args, format);
  vsprintf(statusmsg, format, args);
  va_end(args);

  do_repaint1();
}

static void
do_repaint(Widget w)
{
  int y;


  SetDrawArea(w);
  ClearDrawArea();

  y = starty;
  DrawCenteredText("Time", font, dw, y);
  y += 2*textspacing;
  DrawCenteredText("Cost", font, dw, y);
  y += 2*textspacing;
  DrawCenteredText("Rate", font, dw, y);
  update_display(1, 1, 1);
}

void
bannercb(void * junk)
{
  static int display_state = 0;

  if (cstate != CSTATE_NC)
    return;
  
  if (display_state == 0)
    {
      display_state = 1;
      sa_printf("(C) T. Martinsen");
      AddTimeOut(3000, bannercb, NULL);
    }
  else
    sa_printf("Not connected");
}
