/*
 * This file is part of dial.
 *
 * dial is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 * 
 * dial is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with dial; see the file COPYING.  If not, write to the Free
 * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Copyright 1994 Dominic Giampaolo
 * Copyright 1996 Torsten Martinsen
 *
 * $Id: main.c,v 1.16 1996/04/02 15:17:41 torsten Exp $
 */

#include <stdio.h>
#include <stdlib.h>

#include "dial.h"
#include "readrc.h"

/*
 * Globals
 */
int greycol;
Widget button;
XFont titlefont, buttonfont;

#ifdef TEST
int testing;
#endif

static void init_display(int argc, char **argv);


void main(int argc, char **argv)
{
  init_display(argc, argv);

#ifdef TEST
  testing = argc > 1;
#endif
  
#if MODULES
  load_module("slhc");
  load_module("ppp");
#if BSD_COMP
  load_module("bsd_comp");
#endif
#endif

  parserc(SYSRCFILE);
  parserc(USERRCFILE);

  MainLoop();
}


static void
init_display(int argc, char **argv)
{
  Widget da, da1, quit, stats;
#if SELECTNUMBER
  Widget select;
#endif

  if (OpenDisplay(argc, argv) == 0)
    exit(1);
 
  if (((titlefont = GetFont(TITLEFONT)) == NULL) ||
      ((buttonfont = GetFont(BUTTONFONT)) == NULL))
    {
      fprintf(stderr, "could not get fonts\n");
      exit(1);
    }


  da = MakeDrawArea(WIDTH, HEIGHT, repaint, NULL);
  da1 = MakeDrawArea(WIDTH, FontHeight(buttonfont)*3/2, repaint1, NULL);
  button = MakeButton("  Connect  ", connectcb, NULL);
  quit = MakeButton("Quit", quitcb, NULL);
#if SELECTNUMBER
  select = MakeButton("  Select  ", selectcb, NULL);
  stats = MakeButton(" Stats  ", statscb, NULL);
#else
  stats = MakeButton("  Show statistics  ", statscb, NULL);
#endif

  SetWidgetFont(da, titlefont);
  SetWidgetFont(da1, buttonfont);
  SetWidgetFont(button, buttonfont);
  SetWidgetFont(quit, buttonfont);

  SetWidgetPos(da1, PLACE_UNDER, da, NO_CARE, NULL);
  SetWidgetPos(button, PLACE_UNDER, da1, NO_CARE, NULL);
  SetWidgetPos(quit, PLACE_UNDER, da1, PLACE_RIGHT, button);
#if SELECTNUMBER
  SetWidgetFont(select, buttonfont);
  SetWidgetPos(select, PLACE_UNDER, button, NO_CARE, NULL);
  SetWidgetFont(stats, buttonfont);
  SetWidgetPos(stats, PLACE_UNDER, quit, PLACE_RIGHT, select);
#else
  SetWidgetFont(stats, buttonfont);
  SetWidgetPos(stats, PLACE_UNDER, quit, NO_CARE, NULL);
#endif
  
  ShowDisplay();

  GetStandardColors();
  greycol = GetNamedColor(GREY);
  
  /* Start the clock */
  AddTimeOut(0, clocktick, NULL);
  sa_printf("dial " VERSION);
  AddTimeOut(3000, bannercb, NULL);
}
