/*
 * This file is part of dial.
 *
 * dial is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 * 
 * dial is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with dial; see the file COPYING.  If not, write to the Free
 * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   Copyright 1994 Dominic Giampaolo
 *   Copyright 1996 Torsten Martinsen
 *
 * $Id: stats.c,v 1.5 1996/04/03 05:43:26 torsten Exp $
 */

#include <stdio.h>
#include <stdlib.h>
#include <sys/param.h>
#include <time.h>

#include "dial.h"

static int get2d(char * s);

static char * mname[] = {
  "Jan", "Feb", "Mar", "Apr", "May", "Jun",
  "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
};

static char ** ilist, ** tlist;
static char * items, *totals;


/* 07:45:19 031196-07:46:45 031196  0:01:26   0.62 */
#define STATLINELEN 47
/* Mar 96 99:59:59 123.45 */
#define TOTALLINELEN 22


char **
getStatistics(int * np, char *** totalsp)
{
  FILE * fp;
  int n, i, c, h, m, sec, mon, day, year, curmon;
  char tmp[MAXPATHLEN], * buf, * p, * s, * start, * dest;
  size_t len;
  time_t t_now, * timetotal;
  struct tm * now;
  float f, * costtotal;
  

  if ((fp = fopen(global.logfile, "r")) == NULL)
    {
      sprintf(tmp, "can't open %s", global.logfile);
      perror(tmp);
      return NULL;
    }
  fseek(fp, 0, SEEK_END);
  len = ftell(fp);
  fseek(fp, 0, SEEK_SET);
  buf = malloc(len+1);
  if (fread(buf, 1, len, fp) != len)
    {
      sprintf(tmp, "can't read %s", global.logfile);
      perror(tmp);
      fclose(fp);
      return NULL;
    }
  fclose(fp);
  
  buf[len] = 0;
  for (n = 0, p = buf; *p; ++p)
    if (*p == '\n')
      ++n;
  ilist = malloc(n*sizeof(char **));
  tlist = malloc(n*sizeof(char **));
  items = malloc(n*(STATLINELEN+1));
  totals = malloc(NMONTHS*(TOTALLINELEN+1));

  timetotal = malloc(NMONTHS*sizeof(time_t));
  costtotal = malloc(NMONTHS*sizeof(float));
  for (i = 0; i < NMONTHS; ++i)
    {
      timetotal[i] = 0;
      costtotal[i] = 0.0;
    }

  t_now = time(NULL);
  now = localtime(&t_now);
  curmon = (now->tm_year % 100)*12 + now->tm_mon;
  
  /*
   * Read lines of the form
   * 07:45:19 031196-07:46:45 031196 0:01:26  0.62
   */
  for (i = 0, start = p = buf, dest = items; *p; ++p)
    if (*p == '\n')
      {
	ilist[i++] = dest;
	s = start;
	start = p+1;
	strncpy(dest, s, 32);
	mon = get2d(s+9)-1;
	day = get2d(s+11);
	year = get2d(s+13);
	mon = 12*year + mon;
	c = s[15];
	s += 32;
	if (c == '-')		/* Completed call */
	  {
	    dest += 32;
	    sscanf(s, "%d:%d:%d", &h, &m, &sec);
	    if (curmon - mon < NMONTHS)
	      timetotal[curmon - mon] += h*3600 + m*60 + sec;
	    sprintf(dest, "%2d:%02d:%02d", h, m, sec);
	    while (*s && (*s != ':'))
	      ++s;
	    dest += 8;
	    s += 6;
	  }
	else			/* Call attempt */
	  {
	    dest += 15;
	    strcpy(dest, " The call did not succeed");
	    dest += 25;
	  }
	while (*s && (*s == ' '))
	  ++s;
	sscanf(s, "%f", &f);
	if (curmon - mon < NMONTHS)
	  costtotal[curmon - mon] += f;
	sprintf(tmp, "%.0f", f);
	/* Hack: "%3.2f" does not work */
	for (h = 4-strlen(tmp); h > 0; --h)
	  {
	    *dest++ = ' ';
	    ++s;
	  }
	sprintf(dest, "%.2f", f);
	dest += 6;
	*dest++ = 0;
      }
  ilist[i] = NULL;

  for (i = 0, dest = totals; i < NMONTHS; ++i)
    {
      tlist[i] = dest;
      mon = curmon-i;
      year = mon/12;
      mon -= year*12;
      sec = timetotal[i];
      m = sec/60;
      sec -= m*60;
      h = m/60;
      m -= h*60;
      f = costtotal[i];
      sprintf(tmp, "%.0f", f);
      sprintf(dest, "%s%02d %2d:%02d:%02d %s%.2f",
	      mname[mon], year % 100, h, m, sec, "   "+strlen(tmp), f);
      dest += TOTALLINELEN;
      *dest++ = 0;
    }
  tlist[i] = NULL;
  
  *totalsp = tlist;
  *np = n;
  free(buf);
  free(costtotal);
  free(timetotal);
  return ilist;
}

static int
get2d(char * s)
{
  int d = 0;

  if (*s != ' ')
    d = *s - '0';
  return *++s - '0' + 10*d;
}

void
stat_free(void)
{
  free(ilist);
  free(tlist);
  free(items);
  free(totals);
}
